@@ -8,6 +8,7 @@ pub use implementation::*;
 pub use literal::*;
 pub use parameter::*;
 pub use types::*;
+pub use path::*;
 
 mod attribute;
 mod constant;
@@ -17,6 +18,7 @@ mod implementation;
 mod literal;
 mod parameter;
 mod types;
+mod path;
 
 pub mod processing;
 
