@@ -1,5 +1,6 @@
 use quote::{quote, ToTokens, TokenStreamExt};
 use proc_macro2::TokenStream;
+use crate::ir::Identifier;
 
 #[derive(Debug, PartialEq, Copy, Clone)]
 /// Float Enum
@@ -19,3 +20,12 @@ impl ToTokens for Float {
         tokens.append_all(quote! {#typ})
     }
 }
+
+impl From<Float> for Identifier {
+    fn from(float: Float) -> Self {
+        match float {
+            Float::F32 => "f32".into(),
+            Float::F64 => "f64".into()
+        }
+    }
+}
\ No newline at end of file
