@@ -1,5 +1,6 @@
 use quote::{quote, ToTokens, TokenStreamExt};
 use proc_macro2::TokenStream;
+use crate::ir::Identifier;
 
 #[derive(Debug, Copy, Clone, PartialEq)]
 /// Integer Enum
@@ -32,7 +33,7 @@ pub enum Integer {
 
 impl ToTokens for Integer {
     fn to_tokens(&self, tokens: &mut TokenStream) {
-        let typ = match self {
+        let type_ = match self {
             Integer::U8 => quote! {u8},
             Integer::U16 => quote! {u16},
             Integer::U32 => quote! {u32},
@@ -46,6 +47,25 @@ impl ToTokens for Integer {
             Integer::I128 => quote! {i128},
             Integer::ISize => quote! {isize},
         };
-        tokens.append_all(quote! {#typ})
+        tokens.append_all(quote! {#type_})
     }
-}
\ No newline at end of file
+}
+
+impl From<Integer> for Identifier {
+    fn from(integer: Integer) -> Self {
+        match integer {
+            Integer::U8    => "u8".into(),
+            Integer::U16   => "u16".into(),
+            Integer::U32   => "u32".into(),
+            Integer::U64   => "u64".into(),
+            Integer::U128  => "u128".into(),
+            Integer::USize => "usize".into(),
+            Integer::I8    => "i8".into(),
+            Integer::I16   => "i16".into(),
+            Integer::I32   => "i32".into(),
+            Integer::I64   => "i64".into(),
+            Integer::I128  => "i128".into(),
+            Integer::ISize => "isize".into(),
+        }
+    }
+}
